import time
from calendar import monthrange

from netforce.model import Model,fields,get_model
from netforce.access import get_active_company

class ReportLaborCostSubDetail(Model):
    _name="clinic.report.labor.cost.sub.detail"
    _string="Report Labor Cost Sub Detail"
    _transient=True
    
    _fields={
        "date": fields.Date("Month"),
        "date_from": fields.Date("From", required=True),
        "date_to": fields.Date("To", required=True),
        'staff_id': fields.Many2One("clinic.staff","Staff"),
        "staff_type": fields.Selection([["doctor","Doctor"],["nurse","Nurse"],["staff","Staff"]],"Type"),
        'branch_id': fields.Many2One("clinic.branch","Branch"),
        'department_id': fields.Many2One("clinic.department","Department"),
    }

    def _get_date_from(self,context={}):
        year,month=time.strftime("%Y-%m").split("-")
        return '%s-%s-01'%(year,month)

    def _get_date_to(self,context={}):
        year,month,day=time.strftime("%Y-%m-%d").split("-")
        weekday, total_day=monthrange(int(year), int(month))
        return "%s-%s-%s"%(year,month,total_day)

    def default_get(self,field_names=None,context={},**kw):
        defaults=context.get("defaults",{})
        date_from=defaults.get("date_from")
        if not date_from:
            date_from=self._get_date_from()
        date_to=defaults.get("date_to")
        if not date_to:
            date_to=self._get_date_to()
        staff_type=defaults.get("staff_type","doctor")
        staff_id=int(defaults.get('staff_id', "0"))
        department_id=defaults.get('department_id',None)
        if department_id:
            department_id=int(department_id)
        branch_id=defaults.get('branch_id',None)
        if branch_id:
            branch_id=int(branch_id)
        if not branch_id and department_id:
            dpt=get_model("clinic.department").browse(department_id)
            branch_id=dpt.branch_id.id
        res={
            'date': time.strftime("%Y-%m-%d"),
            'date_from': date_from,
            'date_to': date_to,
            'staff_type': staff_type,
            'staff_id': staff_id and staff_id or None,
            'department_id': department_id,
            'branch_id': branch_id,
        }
        print('res ', res)
        return res

    def get_report_data(self,ids,context={}):
        company_id=get_active_company()
        comp=get_model("company").browse(company_id)
        defaults=self.default_get(context=context)
        date_from=defaults.get("date_from")
        date_to=defaults.get("date_to")
        staff_type=defaults.get("staff_type")
        staff_id=defaults.get("staff_id")
        branch_id=defaults.get("branch_id",None)
        department_id=defaults.get("department_id",None)
        staff_name=''
        dom=[]
        if ids:
            obj=self.browse(ids)[0]
            date_from=obj.date_from
            date_to=obj.date_to
            staff_id=obj.staff_id.id
            staff_name=obj.staff_id.name or ""
            staff_type=obj.staff_type
            department_id=obj.department_id.id
            branch_id=obj.branch_id.id
        dom.append(['date','>=',date_from])
        dom.append(['date','<=',date_to])
        if staff_id and staff_type=='doctor':
            dom.append(['staff_id','=',staff_id])
        elif staff_id and staff_type=='nurse':
            pass
        if staff_type:
            dom.append(['type','=',staff_type])
        if department_id:
            dom.append(['labor_cost_id.cycle_item_id.department_id','=',department_id])
        if branch_id:
            dom.append(['labor_cost_id.cycle_item_id.branch_id','=',branch_id])
        if not staff_id:
            return {}
        def replace_quote(dom=""):
            return dom.replace("'","\"")
        lines=[]
        amount_total=0
        for line in get_model("clinic.labor.cost.line").search_browse(dom):
            lcost=line.labor_cost_id
            citem=lcost.cycle_item_id
            date=citem.date
            dpt=citem.department_id
            amount=line.amount or 0
            qty=line.qty or 0
            if qty:
                amount=amount/qty
            for hdcase in citem.hd_cases:
                if hdcase.state not in ("waiting_payment","paid"):
                    continue
                patient=hdcase.patient_id
                doctor=hdcase.doctor_id
                vals={
                    'date': date,
                    'patient_name': patient.name or "",
                    'department_name': dpt.name or "",
                    'amount': amount,
                }
                if staff_type=='doctor' and doctor.id==staff_id:
                    lines.append(vals)
                    amount_total+=amount
                elif staff_type=='nurse':
                    lines.append(vals)
                    amount_total+=amount
                else:
                    pass
        slines=[]
        no=1
        for line in sorted(lines,key=lambda x: (x['date'], x['department_name'])):
            line['no']=no
            slines.append(line)
            no+=1
            
        data={
            'staff_name': staff_name,
            'staff_id': staff_id,
            'staff_type': staff_type,
            'date_from': date_from,
            'date_to': date_to,
            'comp_name': comp.name or 0,
            'lines': slines,
            'amount_total': amount_total,
        }
        return data

    def onchange_date(self,context={}):
        data=context['data']
        date=data['date']
        year,month,day=date.split("-")
        weekday, total_day=monthrange(int(year), int(month))
        data['date_from']="%s-%s-01"%(year,month)
        data['date_to']="%s-%s-%s"%(year,month,total_day)
        return data

    def onchange_type(self,context={}):
        data=context['data']
        data['staff_id']=None
        return data

ReportLaborCostSubDetail.register()
